package com.op.wms.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.op.wms.mapper.PowderChargeOrderMapper;
import com.op.wms.domain.PowderChargeOrder;
import com.op.wms.service.IPowderChargeOrderService;

/**
 * 粉料配料Service业务层处理
 * 
 * @author Open Platform
 * @date 2023-07-10
 */
@Service
public class PowderChargeOrderServiceImpl implements IPowderChargeOrderService {
	@Autowired
	private PowderChargeOrderMapper powderChargeOrderMapper;

	/**
	 * 查询粉料配料
	 * 
	 * @param ID 粉料配料主键
	 * @return 粉料配料
	 */
	@Override
	public PowderChargeOrder selectPowderChargeOrderByID(String ID) {
		return powderChargeOrderMapper.selectPowderChargeOrderByID(ID);
	}

	/**
	 * 查询粉料配料列表
	 * 
	 * @param powderChargeOrder 粉料配料
	 * @return 粉料配料
	 */
	@Override
	public List<PowderChargeOrder> selectPowderChargeOrderList(PowderChargeOrder powderChargeOrder) {
		return powderChargeOrderMapper.selectPowderChargeOrderList(powderChargeOrder);
	}

	/**
	 * 新增粉料配料
	 * 
	 * @param powderChargeOrder 粉料配料
	 * @return 结果
	 */
	@Override
	public int insertPowderChargeOrder(PowderChargeOrder powderChargeOrder) {
		return powderChargeOrderMapper.insertPowderChargeOrder(powderChargeOrder);
	}

	/**
	 * 修改粉料配料
	 * 
	 * @param powderChargeOrder 粉料配料
	 * @return 结果
	 */
	@Override
	public int updatePowderChargeOrder(PowderChargeOrder powderChargeOrder) {
		return powderChargeOrderMapper.updatePowderChargeOrder(powderChargeOrder);
	}

	/**
	 * 批量删除粉料配料
	 * 
	 * @param IDs 需要删除的粉料配料主键
	 * @return 结果
	 */
	@Override
	public int deletePowderChargeOrderByIDs(String[] IDs) {
		return powderChargeOrderMapper.deletePowderChargeOrderByIDs(IDs);
	}

	/**
	 * 删除粉料配料信息
	 * 
	 * @param ID 粉料配料主键
	 * @return 结果
	 */
	@Override
	public int deletePowderChargeOrderByID(String ID) {
		return powderChargeOrderMapper.deletePowderChargeOrderByID(ID);
	}
}
